﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using game.Model;

namespace game.Pages
{
    public partial class PanoramaPage : PhoneApplicationPage
    {
        ScoreManager scoreManager;
        GameSettings gameSettings;
        SoundEffectAction soundEffect;

        public PanoramaPage()
        {
            InitializeComponent();
            resetScoresButton.Click += new RoutedEventHandler(resetScores);
            scoreManager = new ScoreManager();
            ReadWrite rw = new ReadWrite();
            soundEffect = new SoundEffectAction();
            soundEffect.SetupSoundEffect("sounds/goodmove.wav");
            gameSettings = new GameSettings(rw.LoadData("settings.txt"));

            refreshHighScores();
        }

        protected override void OnNavigatedTo(System.Windows.Navigation.NavigationEventArgs e)
        {
            String view = string.Empty;
            if (this.NavigationContext != null)
                if (this.NavigationContext.QueryString.TryGetValue("view", out view))
                    this.SetDefaultItem(int.Parse(view));
        }

        void resetScores(object sender, RoutedEventArgs e)
        {
            if (gameSettings.getEffectsSound())
            {
                soundEffect.SetupSoundEffect("sounds/click.wav");
                soundEffect.Play();
            }
            scoreManager.reset();
            this.refreshHighScores();
        }

        public void refreshHighScores() {
            
            List<Score> scores = scoreManager.getScores();
            
            highScoreBody.Children.Clear();


            //set cols and rows definition
            for (int i = 0; i < scores.Count; i++)
            {
                RowDefinition rd = new RowDefinition();
                rd.Height = GridLength.Auto;
                highScoreBody.RowDefinitions.Add(rd);
            }
            
            for (int j = 0; j < 4; j++)
            {
                ColumnDefinition cd = new ColumnDefinition();
                cd.Width= GridLength.Auto;
                highScoreBody.ColumnDefinitions.Add(cd);
            }

            //fill it with scores
            int row = 0;
            foreach (Score s in scores) {
                //name
                TextBlock nameLabel = new TextBlock();
                nameLabel.Text = s.name;
                nameLabel.Width = 100;
                nameLabel.SetValue(Grid.RowProperty, row);
                nameLabel.SetValue(Grid.ColumnProperty, 0);
                //date
                TextBlock dateLabel = new TextBlock();
                dateLabel.Text = s.date;
                dateLabel.Width = 100;
                dateLabel.SetValue(Grid.RowProperty, row);
                dateLabel.SetValue(Grid.ColumnProperty, 1);
                //level
                TextBlock levelLabel = new TextBlock();
                levelLabel.Text = s.level;
                levelLabel.Width = 100;
                levelLabel.SetValue(Grid.RowProperty, row);
                levelLabel.SetValue(Grid.ColumnProperty, 2);
                //points
                TextBlock pointsLabel = new TextBlock();
                pointsLabel.Text = s.points;
                pointsLabel.Width = 100;
                pointsLabel.SetValue(Grid.RowProperty, row);
                pointsLabel.SetValue(Grid.ColumnProperty, 3);

                highScoreBody.Children.Add(nameLabel);
                highScoreBody.Children.Add(dateLabel);
                highScoreBody.Children.Add(levelLabel);
                highScoreBody.Children.Add(pointsLabel);
                row++;
            }

        }

        public void SetDefaultItem(int position)
        {
            Panorama.DefaultItem = Panorama.Items[position];
        }
    }
}